==> nextcloud-20.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/dashboard/l10n/hu.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Irányítópult",
    "Dashboard app" : "Irányítópult modul",
    "Show something" : "Mutass valamit",
    "Customize" : "Testreszab",
    "Edit widgets" : "Modulok szerkesztése",
    "Get more widgets from the app store" : "Tölts le további modulokat az app áruházból",
    "Change background image" : "Háttérkép megváltoztatása",
    "Weather service" : "Időjárás",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "A magánélet védelmében az információt az Ön nevében a Nextcloud szerver  kéri le, így az Ön személyes adatai nem kerülnek az időjárási adatok szolgáltatójához.",
    "Weather data from Met.no" : "Időjárási adatok a Met.no-tól",
    "geocoding with Nominatim" : "geokódolás a Nominatim-al",
    "elevation data from OpenTopoData" : "magassági adatok az OpenTopoData-tól",
    "Weather" : "Időjárás",
    "Status" : "Állapot",
    "Good evening, {name}" : "Jó estét, (name)",
    "Good evening" : "Jó estét",
    "Good afternoon, {name}" : "Jó napot, (name)",
    "Good afternoon" : "Jó napot",
    "Good morning, {name}" : "Jó reggelt, (name)",
    "Good morning" : "Jó reggelt",
    "Good night, {name}" : "Jó éjszakát, (name)",
    "Good night" : "Jó éjszakát",
    "Pick from files" : "Választás a fájlok közül",
    "Default images" : "Alapértelmezett képek",
    "Plain background" : "Egyszerű háttér",
    "Insert from {productName}" : "Beillesztés (productName)-ból"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.1-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/dashboard/l10n/hu.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Irányítópult",
    "Dashboard app" : "Irányítópult modul",
    "Show something" : "Mutass valamit",
    "Customize" : "Testreszabás",
    "Edit widgets" : "Modulok szerkesztése",
    "Get more widgets from the app store" : "Tölts le további modulokat az app áruházból",
    "Change background image" : "Háttérkép megváltoztatása",
    "Weather service" : "Időjárás",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "A magánélet védelmében az információt az Ön nevében a Nextcloud szerver  kéri le, így az Ön személyes adatai nem kerülnek az időjárási adatok szolgáltatójához.",
    "Weather data from Met.no" : "Időjárási adatok a Met.no-tól",
    "geocoding with Nominatim" : "geokódolás a Nominatim-al",
    "elevation data from OpenTopoData" : "magassági adatok az OpenTopoData-tól",
    "Weather" : "Időjárás",
    "Status" : "Állapot",
    "Good morning" : "Jó reggelt",
    "Good morning, {name}" : "Jó reggelt, {name}",
    "Good afternoon" : "Jó napot",
    "Good afternoon, {name}" : "Jó napot, {name}",
    "Good evening" : "Jó estét",
    "Good evening, {name}" : "Jó estét, {name}",
    "Hello" : "Üdv",
    "Hello, {name}" : "Üdv {name}!",
    "Pick from Files" : "Választás a fájlok közül",
    "Default images" : "Alapértelmezett képek",
    "Plain background" : "Egyszerű háttér",
    "Insert from {productName}" : "Beillesztés {productName}-ból",
    "Good night, {name}" : "Jó éjszakát, {name}",
    "Good night" : "Jó éjszakát",
    "Pick from files" : "Választás a fájlok közül"
},
"nplurals=2; plural=(n != 1);");
